==> cookieconsent_3.x_6.6.0.zip: lib/ckMonster/Handlers/IframeExtensions/BaseVendor.php <==
<?php


namespace ckMonster\Handlers\IframeExtensions;


use Joomla\CMS\Filesystem\File;

abstract class BaseVendor implements IframeInterface
{
	const needle = '';

	protected $url;
	protected $vendor;

	public function __construct(string $src)
	{
		$this->url = $src;
	}

	public static function check(string $src): bool
	{
		return (strpos($src, static::needle) !== false);
	}

	public function getUrl(): string
	{
		return $this->url;
	}

	public function getProxyThumb($width): ?string
	{
		$url = $this->getThumbnail($width);
		$hashed = sha1($this->url);

		$path = parse_url($url, PHP_URL_PATH);
		$ext = pathinfo($path, PATHINFO_EXTENSION) ?? 'jpeg';

		$img_path = "/media/plg_cookieconsent/thumbs/{$hashed}.{$ext}";
		$dest = JPATH_SITE . $img_path;

		$thumb = $this->cURL($url);

		File::write($dest, $thumb);

		return \JURI::base(true) . $img_path;
	}

	public function getThumbnail($width): ?string
	{
		return null;
	}

	public function getVendorName(): string
	{
		return $this->vendor;
	}

	protected function getQuery(?string $key = null)
	{
		$parts = $this->getUrlParts($key);

		if (isset($parts['query'])) {
			parse_str($parts['query'], $query);
		} else {
			$query = null;
		}

		return ($key) ? $query[$key] : $query;
	}

	protected function getUrlParts(?string $key)
	{
		$parts = parse_url($this->getUrl());
		return ($key) ? $parts[$key] : $parts;
	}

	protected function getOembed(int $width): ?object
	{
		return null;
	}

	protected function getHttpResponseCode(string $url): int
	{
	    $headers = get_headers($url);
	    return substr($headers[0], 9, 3);
	}

	protected function cURL(string $url, array $parameters = []): string
	{
		$query = http_build_query($parameters);

		$curl = curl_init();

		curl_setopt_array($curl, array(
			CURLOPT_URL => "$url?$query",
			CURLOPT_RETURNTRANSFER => true,
			CURLOPT_ENCODING => "",
			CURLOPT_MAXREDIRS => 10,
			CURLOPT_TIMEOUT => 3,
			CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
			CURLOPT_CUSTOMREQUEST => "GET",
			CURLOPT_POSTFIELDS => "",
			CURLOPT_HTTPHEADER => array(
				"Accept: application/json",
				"Referer: " . \JUri::root(),
			),
		));

		$response = curl_exec($curl);
		$err = curl_error($curl);
		$errNo = curl_errno($curl);

		curl_close($curl);

		if ($err) {
			throw new Exception($err, $errNo);
		}
		return $response;
	}
}

==> cookieconsent_3.x_6.7.1.zip: lib/ckMonster/Handlers/IframeExtensions/BaseVendor.php <==
<?php


namespace ckMonster\Handlers\IframeExtensions;


use Joomla\CMS\Filesystem\File;

abstract class BaseVendor implements IframeInterface
{
	const needle = '';

	protected $url;
	protected $vendor;

	public function __construct(string $src)
	{
		$this->url = $src;
	}

	public static function check(string $src): bool
	{
		return (strpos($src, static::needle) !== false);
	}

	public function getUrl(): string
	{
		return $this->url;
	}

	public function getProxyThumb($width): ?string
	{
		$url = $this->getThumbnail($width);
		$hashed = sha1($this->url);

		$path = parse_url($url, PHP_URL_PATH);
		$ext = pathinfo($path, PATHINFO_EXTENSION);

		if (empty($ext) || !is_string($ext)) {
			$ext = 'jpeg';
		}

		$img_path = "/media/plg_cookieconsent/thumbs/{$hashed}.{$ext}";
		$dest = JPATH_SITE . $img_path;

		if (!File::exists($dest)) {
			$thumb = $this->cURL($url);
			File::write($dest, $thumb);
		}

		return \JURI::base(true) . $img_path;
	}

	public function getThumbnail($width): ?string
	{
		return null;
	}

	public function getVendorName(): string
	{
		return $this->vendor;
	}

	protected function getQuery(?string $key = null)
	{
		$parts = $this->getUrlParts($key);

		if (isset($parts['query'])) {
			parse_str($parts['query'], $query);
		} else {
			$query = null;
		}

		return ($key) ? $query[$key] : $query;
	}

	protected function getUrlParts(?string $key)
	{
		$parts = parse_url($this->getUrl());
		return ($key) ? $parts[$key] : $parts;
	}

	protected function getOembed(int $width): ?object
	{
		return null;
	}

	protected function getHttpResponseCode(string $url): int
	{
	    $headers = get_headers($url);
	    return substr($headers[0], 9, 3);
	}

	protected function cURL(string $url, array $parameters = []): string
	{
		$query = http_build_query($parameters);

		$curl = curl_init();

		curl_setopt_array($curl, array(
			CURLOPT_URL => "$url?$query",
			CURLOPT_RETURNTRANSFER => true,
			CURLOPT_ENCODING => "",
			CURLOPT_MAXREDIRS => 10,
			CURLOPT_TIMEOUT => 3,
			CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
			CURLOPT_CUSTOMREQUEST => "GET",
			CURLOPT_POSTFIELDS => "",
			CURLOPT_HTTPHEADER => array(
				"Accept: application/json",
				"Referer: " . \JUri::root(),
			),
		));

		$response = curl_exec($curl);
		$err = curl_error($curl);
		$errNo = curl_errno($curl);

		curl_close($curl);

		if ($err) {
			throw new Exception($err, $errNo);
		}
		return $response;
	}
}
